
#ifndef EL__MIME_BACKEND_DEFAULT_H
#define EL__MIME_BACKEND_DEFAULT_H

#include "main/module.h"
#include "mime/backend/common.h"

extern struct mime_backend default_mime_backend;
extern struct module default_mime_module;

#endif
